@@ -147,13 +147,17 @@ void Document::clear()
  */
 bool Document::open(const Glib::ustring &filename, const Glib::ustring &encoding, bool clear_doc)
 {
-	// 27/28
+	//SE::getInstance()->getSubtitleView()->unset_model();
+
+	// 29
 	//
-	//std::clock_t start = std::clock();
+	std::clock_t start = std::clock();
 
 	bool res = _open(filename, encoding, clear_doc);
 
-	//std::cout << "timer: " << double(std::clock() - start) / CLOCKS_PER_SEC << std::endl;
+	std::cout << "timer: " << double(std::clock() - start) / CLOCKS_PER_SEC << std::endl;
+
+	//SE::getInstance()->getSubtitleView()->set_model(m_subtitleModel);
 
 	return res;
 }
