@@ -145,6 +145,7 @@ SubtitleEditor::~SubtitleEditor()
 
 	Gtk::AccelMap::save(path_se_accelmap);
 
+	//ask_to_save_on_exit();
 
 	se_debug_message(SE_DEBUG_APP, "Delete dialog");
 
@@ -154,6 +155,18 @@ SubtitleEditor::~SubtitleEditor()
 	delete m_dialogChangeFPS;
 }
 
+/*
+ *
+ */
+void SubtitleEditor::show()
+{
+	// cela rend le lancement de l'app plus rapide s'il on connect
+	// le model a la vue maintenant ...
+	getSubtitleView()->set_model(getDocument()->get_subtitle_model());
+	
+	Gtk::Window::show();
+}
+
 /*
  *
  */
@@ -268,6 +281,27 @@ void SubtitleEditor::on_new_subtitle()
 	setStatusbar(_("New Document"));
 }
 
+/*
+ *
+ */
+void SubtitleEditor::ask_to_save_on_exit()
+{
+	bool askToSaveOnExit = false;
+
+	if( Config::getInstance().get_value_bool("general", "ask-to-save-on-exit", askToSaveOnExit))
+	{
+		if(askToSaveOnExit)
+		{
+			Gtk::MessageDialog dialog(*this, 
+					_("Do you want saving the subtitle before the exit ?"), 
+					false, Gtk::MESSAGE_QUESTION , Gtk::BUTTONS_YES_NO ,true);
+
+			if(dialog.run() == Gtk::RESPONSE_YES)
+				on_save_subtitle();		
+		}
+	}
+}
+
 /*
  *
  */
@@ -275,9 +309,8 @@ void SubtitleEditor::on_quit()
 {
 	se_debug(SE_DEBUG_APP);
 
-	//Gtk::MessageDialog dialog(*this, "Are you sure ?", false, Gtk::MESSAGE_QUESTION , Gtk::BUTTONS_YES_NO ,true);
-	//if(dialog.run() == Gtk::RESPONSE_YES)
-		Gtk::Main::quit();
+	
+	Gtk::Main::quit();
 }
 
 /*
@@ -1455,7 +1488,8 @@ void SubtitleEditor::on_move_subtitle_text_forward()
 	Gtk::TreeIter it = getSubtitleView()->getSelected();
 	if(it)
 	{
-		// recupere tous le textes des sous-titres a partir de la selection
+		/*
+		// recupere le texte des sous-titres  partir de la selection
 		std::vector<Glib::ustring> strings;
 
 		for(Gtk::TreeIter it2=it; it2; ++it2)
@@ -1475,7 +1509,8 @@ void SubtitleEditor::on_move_subtitle_text_forward()
 		// ajoute le derniers
 		Gtk::TreeIter last = getDocument()->get_subtitle_model()->append();
 
-		SubtitleModifier(last).set_text(strings.back());
+		SubtitleModifier last_iter(last).set_text(strings.back());
+		*/
 	}
 }
 
