@@ -74,6 +74,8 @@ public:
 	 */
 	static SubtitleEditor* getInstance();
 	
+	void show();
+
 	void open_subtitle(const Glib::ustring &file);
 	void open_movie(const Glib::ustring &uri);
 
@@ -174,6 +176,8 @@ public:
 	
 	template<class T>
 	bool create_dialog(const Glib::ustring &name, T **dialog);
+
+	void ask_to_save_on_exit();
 protected:
 
 	//Signal		m_signal;
