@@ -118,8 +118,9 @@ bool SubtitleMPL2::open(const Glib::ustring &filename, const Glib::ustring &enco
 			characters_to_newline(text, "|");
 		
 			subtitle.set_text(text);
-			subtitle.set_start( SubtitleTime((long int)(start*ds)));
-			subtitle.set_end( SubtitleTime((long int)(end*ds)));
+			subtitle.set_start_and_end(
+					SubtitleTime((long int)(start*ds)),
+					SubtitleTime((long int)(end*ds)));
 		}
 	}
 
