@@ -209,8 +209,8 @@ Gtk::TreeIter SubtitleModel::getLast()
  */
 unsigned int	SubtitleModel::getSize()
 {
-	Gtk::TreeNodeChildren rows = children();
-	return rows.size();
+	//Gtk::TreeNodeChildren rows = children();
+	return children().size();
 }
 
 
