@@ -99,6 +99,8 @@ bool SubtitleSubRip::open(const Glib::ustring &filename, const Glib::ustring &en
 	}
 
 	std::string line;
+	SubtitleModifier subtitle;
+
 	while(!file.eof() && std::getline(file, line))
 	{
 		unsigned int num = 0;
@@ -126,7 +128,7 @@ bool SubtitleSubRip::open(const Glib::ustring &filename, const Glib::ustring &en
 							break;
 						else
 						{
-							if(count > 0) // s'il y a deja une ligne alors on utlise le | pour le retour a la ligne
+							if(count > 0) 
 								text += get_newline();
 
 							text += line;
@@ -134,11 +136,13 @@ bool SubtitleSubRip::open(const Glib::ustring &filename, const Glib::ustring &en
 						}
 					}
 
-					SubtitleModifier subtitle(m_subtitleModel->append());
+					subtitle.init( m_subtitleModel->append() );
 
 					subtitle.set_text(text);
-					subtitle.set_start(SubtitleTime(start[0], start[1], start[2], start[3]));
-					subtitle.set_end(SubtitleTime(end[0], end[1], end[2], end[3]));
+
+					subtitle.set_start_and_end(
+							SubtitleTime(start[0], start[1], start[2], start[3]),
+							SubtitleTime(end[0], end[1], end[2], end[3]));
 				}
 			}
 		}
