@@ -10,6 +10,8 @@
 #include "SubtitleSSA.h"
 #include "SubtitleSubViewer2.h"
 #include "SubtitleMPsub.h"
+#include "SubtitleEncorePAL.h"
+#include "SubtitleEncoreNTSC.h"
 #include "utility.h"
 
 /*
@@ -88,6 +90,8 @@ SubtitleSystem& SubtitleSystem::getInstance()
 		REGISTER_SUBTITLE(SubtitleMPL2);
 		REGISTER_SUBTITLE(SubtitleSubViewer2);
 		REGISTER_SUBTITLE(SubtitleMPsub);
+		REGISTER_SUBTITLE(SubtitleEncorePAL);
+		REGISTER_SUBTITLE(SubtitleEncoreNTSC);
 #ifdef ENABLE_TTXT
 		REGISTER_SUBTITLE(SubtitleTTXT);
 #endif
