@@ -72,45 +72,10 @@ SubtitleTime::SubtitleTime(const long &total)
 
 	totalmsecs = getMSecs(*this);
 }
+
 /*
-SubtitleTime::SubtitleTime(const std::string &str)
-{
-	try
-	{
-		hours = mins = secs = msecs = totalmsecs = 0;
-
-		std::string::size_type pos=0, end=0;
-
-		// hours
-		end = str.find(":", pos);
-		from_string(str.substr(pos, end), hours);
-		pos = end+1;
-
-		// minutes
-		end = str.find(":", pos);
-		from_string(str.substr(pos, end), mins);
-		pos = end+1;
-
-		// seconds
-		double ms = 0.0;
-
-		end = str.size();
-
-		from_string(str.substr(pos, end), ms);
-
-		// split into seconds and fraction
-		secs = (int)ms;
-
-		msecs = (int)((ms - secs)*1000+0.5);
-
-		totalmsecs = getMSecs(*this);
-	}
-	catch(...)
-	{
-		hours = mins = secs = msecs = totalmsecs = 0;
-	}
-}
-*/
+ *
+ */
 SubtitleTime::SubtitleTime(const Glib::ustring &str)
 {
 	try
@@ -149,17 +114,17 @@ SubtitleTime::SubtitleTime(const Glib::ustring &str)
 	}
 }
 
-/**
+/*
  *
-**/
+ */
 SubtitleTime::SubtitleTime(const int &h, const int &m, const int &s, const int &ms)
 {
 	set(h,m,s,ms);
 }
 
-/**
+/*
  *
-**/
+ */
 void SubtitleTime::set(const int &h, const int &m, const int &s, const int &ms)
 {
 	hours = h;
@@ -170,76 +135,110 @@ void SubtitleTime::set(const int &h, const int &m, const int &s, const int &ms)
 	totalmsecs = getMSecs(*this);
 }
 
+/*
+ *
+ */
 void SubtitleTime::initTotalMSecs()
 {
 	totalmsecs = getMSecs(*this);
 }
 
-
+/*
+ *
+ */
 void SubtitleTime::move(long msecs)
 {
 	totalmsecs+=msecs;
 	*this = getTime2MSecs(totalmsecs);
 }
 
-
-
+/*
+ *
+ */
 SubtitleTime SubtitleTime::operator-(const SubtitleTime &b) const
 {
 	long total = totalmsecs - b.totalmsecs;
 	return getTime2MSecs(total);
 }
 
+/*
+ *
+ */
 SubtitleTime SubtitleTime::operator+(const SubtitleTime &b) const
 {
 	long total = totalmsecs + b.totalmsecs;
 	return getTime2MSecs(total);
 }
 
+/*
+ *
+ */
 double SubtitleTime::operator/(const SubtitleTime &b) const
 {
 	double total = totalmsecs / b.totalmsecs;
 	return total;
 }
 
+/*
+ *
+ */
 SubtitleTime SubtitleTime::operator*(const double &mult) const
 {
 	double total = (double)(totalmsecs * mult);
 	return getTime2MSecs((long int)total);
 }
 
-
+/*
+ *
+ */
 bool SubtitleTime::operator>(const SubtitleTime &time)
 {
 	return totalmsecs > time.totalmsecs;
 }
 
+/*
+ *
+ */
 bool SubtitleTime::operator==(const SubtitleTime &time)
 {
 	return totalmsecs == time.totalmsecs;
 }
 
+/*
+ *
+ */
 bool SubtitleTime::operator!=(const SubtitleTime &time)
 {
 	return totalmsecs != time.totalmsecs;
 }
 
+/*
+ *
+ */
 bool SubtitleTime::operator>=(const SubtitleTime &time)
 {
 	return totalmsecs >= time.totalmsecs;
 }
 
+/*
+ *
+ */
 bool SubtitleTime::operator<(const SubtitleTime &time)
 {
 	return totalmsecs < time.totalmsecs;
 }
 
+/*
+ *
+ */
 bool SubtitleTime::operator<=(const SubtitleTime &time)
 {
 	return totalmsecs <= time.totalmsecs;
 }
 
-
+/*
+ *
+ */
 Glib::ustring SubtitleTime::str() const
 {
 	return getTime2String(*this);
@@ -317,3 +316,23 @@ Glib::ustring SubtitleTime::null()
 {
 	return "0:00:00.000";
 }
+
+/*
+ *	calcul le temps à partir d'une frame et d'un framerate
+ *	ex: (450, 23.976)
+ */
+SubtitleTime SubtitleTime::frame_to_time(const long int& frame, const float& framerate)
+{
+	// secs = frame / framerate
+	// msecs = secs * 1000
+
+	return SubtitleTime((long)((frame / framerate) * 1000));
+}
+
+/*
+ *
+ */
+long int SubtitleTime::time_to_frame(const SubtitleTime& time, const float& framerate)
+{
+	return (long int)round((time.totalmsecs * framerate) / 1000);
+}
