@@ -90,6 +90,18 @@ public:
 	 *	return "0:00:00.000"
 	 */
 	static Glib::ustring null();
+
+	/*
+	 *	calcul le temps à partir d'une frame et d'un framerate
+	 *	ex: (450, 23.976)
+	 */
+	static SubtitleTime frame_to_time(const long int& frame, const float& framerate);
+
+	/*
+	 *
+	 */
+	static long int time_to_frame(const SubtitleTime& time, const float& framerate);
+
 public:
 	int		hours;
 	int		mins;
