@@ -844,6 +844,7 @@ TimingSystem::TimingSystem(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Gl
 
 	refGlade->get_widget("spin-zoom", m_spinZoom);
 	refGlade->get_widget("spin-scale", m_spinScale);
+	refGlade->get_widget("toggle-button-scroll", m_toggleButtonScroll);
 
 	refGlade->get_widget("button-play-previous-subtitle", m_buttonPreviousSubtitle);
 	refGlade->get_widget("button-play-current-subtitle", m_buttonPlay);
@@ -1234,7 +1235,8 @@ void TimingSystem::on_signal_subtitle_view_selection_changed(Gtk::TreeIter it)
 		if((ps < x || ps > w))// && !(pe > current_x && pe < current_x))
 		{
 			// TODO verifier qu'on est bien dans la vue, sinon on y va
-			m_scrollbarWavform->set_value(ps);
+			if(m_toggleButtonScroll->get_active())
+				m_scrollbarWavform->set_value(ps);
 		}
 	}
 }
@@ -1276,12 +1278,15 @@ void TimingSystem::on_media_timeout()
  */
 void TimingSystem::update_view_from_cursor(gint64 time)
 {
-	gint64 pos = m_drawingAreaWaveform->get_pos_by_time(time);
+	if(m_toggleButtonScroll->get_active())
+	{
+		gint64 pos = m_drawingAreaWaveform->get_pos_by_time(time);
 
-	if( pos < m_drawingAreaTime->get_start_area())
-		m_scrollbarWavform->set_value(pos);
-	else if(pos > m_drawingAreaTime->get_end_area())
-		m_scrollbarWavform->set_value(pos);
+		if( pos < m_drawingAreaTime->get_start_area())
+			m_scrollbarWavform->set_value(pos);
+		else if(pos > m_drawingAreaTime->get_end_area())
+			m_scrollbarWavform->set_value(pos);
+	}
 }
 
 /*
