@@ -191,6 +191,16 @@ void dialog_error(const Glib::ustring &primary_text, const Glib::ustring &second
 #define ISO_639_DOMAIN	"iso_639"
 #define ISO_3166_DOMAIN	"iso_3166"
 
+/*
+ * max length of sscanf'ed fields + 1
+ */
+#define ISO_639_2_TERMINOLOGY_LEN	4
+#define ISO_639_2_BIBLIOGRAPHY_LEN	4
+#define ISO_639_1_CODE_LEN	3
+#define ISO_639_NAME_LEN	256
+
+#define ISO_3166_ALPHA2_LEN	3
+#define ISO_3166_NAME_LEN	256
 
 static bool map_iso_639_initialised = false;
 static bool map_iso_3166_initialised = false;
@@ -206,27 +216,40 @@ void read_iso_639(const Glib::ustring &filename)
 	std::ifstream file(filename.c_str());
 	if(!file)
 	{
-		std::cerr << "Can open file: " << filename << std::endl;
+		std::cerr << "Cannot open file: " << filename << std::endl;
 		return;
 	}
 
 	std::string line;
 	
-	char terminology[256];
-	char bibliography[256];
-	char code[256];
-	char name[256];
+
+	gchar *format = g_strdup_printf("%%%is %%%is %%%is %%n%%%ic%%n",
+			ISO_639_2_TERMINOLOGY_LEN - 1,
+			ISO_639_2_BIBLIOGRAPHY_LEN - 1,
+			ISO_639_1_CODE_LEN - 1,
+			ISO_639_NAME_LEN - 1);
+
+	char terminology[ISO_639_2_TERMINOLOGY_LEN];
+	char bibliography[ISO_639_2_BIBLIOGRAPHY_LEN];
+	char code[ISO_639_1_CODE_LEN];
+	char name[ISO_639_NAME_LEN];
+	int plen, nlen;
+	
 	while(!file.eof() && std::getline(file, line))
 	{
 		if(!line.empty() && line[0] != '#')
 		{
-			if(sscanf(line.c_str(), "%s %s %s %s", terminology, bibliography, code, name) > 0)
+			if(sscanf(line.c_str(), format, terminology, bibliography, code, &plen, name, &nlen) > 0)
 			{
-				if(std::string(code) != "XX")
+				if(nlen - plen > 0 && std::string(code) != "XX")
+				{
+					name[nlen - plen] = '\0';
 					map_iso_639[code]=name;
+				}
 			}
 		}
 	}
+	g_free(format);
 
 	file.close();
 
@@ -242,24 +265,31 @@ void read_iso_3166(const Glib::ustring &filename)
 	std::ifstream file(filename.c_str());
 	if(!file)
 	{
-		std::cerr << "Can open file: " << filename << std::endl;
+		std::cerr << "Cannot open file: " << filename << std::endl;
 		return;
 	}
 
 	std::string line;
-	
-	char code[256];
-	char name[256];
+
+	gchar *format = g_strdup_printf("%%%is %%n%%%ic%%n",
+			ISO_3166_ALPHA2_LEN - 1,
+			ISO_3166_NAME_LEN - 1);
+	char code[ISO_3166_ALPHA2_LEN];
+	char name[ISO_3166_NAME_LEN];
+	int plen, nlen;
+
 	while(!file.eof() && std::getline(file, line))
 	{
 		if(!line.empty() && line[0] != '#')
 		{
-			if(sscanf(line.c_str(), "%s %s", code, name) > 0)
+			if(sscanf(line.c_str(), format, code, &plen, name, &nlen) > 0)
 			{
+				name[nlen - plen] = '\0';
 				map_iso_3166[code]=name;
 			}
 		}
 	}
+	g_free(format);
 
 	file.close();
 
@@ -303,7 +333,7 @@ Glib::ustring get_iso_name_for_lang_code(const Glib::ustring &code)
 	else if(code.size() == 5)
 	{
 		c1 = code.substr(0, 2);
-		c2 = code.substr(3,5);
+		c2 = code.substr(3, 5);
 
 		Glib::ustring s639 = dgettext(ISO_639_DOMAIN, map_iso_639[c1].c_str());
 		Glib::ustring s3166 = dgettext(ISO_3166_DOMAIN, map_iso_3166[c2].c_str());
@@ -322,3 +352,62 @@ Glib::ustring get_iso_name_for_lang_code(const Glib::ustring &code)
 }
 
 #endif //HAVE_ISO_CODES
+
+
+#include "SubtitleTime.h"
+
+/*
+ *
+ */
+SpinButtonTiming::SpinButtonTiming(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+:Gtk::SpinButton(cobject)
+{
+	set_increments(100, 1);
+
+	set_use_negative(false);
+
+	int width, height;
+
+	create_pango_layout("00:00:00.000")->get_pixel_size(width, height);
+
+	set_size_request(width + 25, -1);
+}
+
+/*
+ *
+ */
+int SpinButtonTiming::on_input(double *new_value)
+{
+	Glib::ustring text = get_text();
+
+	if(SubtitleTime::validate(text))
+		*new_value = (double) SubtitleTime(text).totalmsecs;
+
+	return true;
+}
+
+/*
+ *
+ */
+bool SpinButtonTiming::on_output()
+{
+	//bool state = Gtk::SpinButton::on_output();
+	//return state;
+	
+	set_numeric(false);
+
+	set_text(SubtitleTime((long int)get_value()).str());
+
+	set_numeric(true);
+
+	return true;
+}
+
+void SpinButtonTiming::set_use_negative(bool use_negative)
+{
+	if(use_negative)
+		set_range(-86399999, 86399999);
+	else
+		set_range(0, 86399999);
+}
+
