@@ -149,4 +149,35 @@ void dialog_warning(const Glib::ustring &primary_text, const Glib::ustring &seco
 void dialog_error(const Glib::ustring &primary_text, const Glib::ustring &secondary_text);
 
 
+/*
+ *	devired with glade 
+ */
+
+#include <gtkmm/comboboxtext.h>
+#include <gtkmm/spinbutton.h>
+#include <libglademm/xml.h>
+
+class ComboBoxText : public Gtk::ComboBoxText
+{
+public:
+	ComboBoxText(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+	:Gtk::ComboBoxText(cobject)
+	{
+	}
+};
+
+/*
+ *
+ */
+class SpinButtonTiming : public Gtk::SpinButton
+{
+public:
+	SpinButtonTiming(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+
+	void set_use_negative(bool use_negative);
+protected:
+	virtual int on_input(double *new_value);
+	virtual bool on_output();
+};
+
 #endif//_utility_h
